@@ -1,7 +1,5 @@
 /*
- * $Id$
- * $Source$
- * Copyright 1994-2011 Brad Lanam, Walnut Creek, CA
+ * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
  */
 
 /********************************************************/
@@ -402,9 +400,8 @@ di_getDiskInfo (diskInfo, diCount)
  *
  */
 
-# define DI_GETDISKINFO_DEF 1
-
-# define MSDOS_BUFFER_SIZE          256
+# define DI_GETDISKINFO_DEF   1
+# define MSDOS_BUFFER_SIZE    256
 
 void
 # if _proto_stdc
@@ -427,9 +424,10 @@ di_getDiskInfo (diskInfo, diCount)
 
 # if _lib_GetDiskFreeSpaceEx
     if (debug > 0) { printf ("# getDiskInfo: GetDiskFreeSpaceEx\n"); }
-# endif
-# if _lib_GetDiskFreeSpace
-    if (debug > 0) { printf ("# getDiskInfo: GetDiskFreeSpace\n"); }
+# else
+#  if _lib_GetDiskFreeSpace
+      if (debug > 0) { printf ("# getDiskInfo: GetDiskFreeSpace\n"); }
+#  endif
 # endif
     if (debug > 0) { printf ("# getDiskInfo: GetVolumeInformation\n"); }
     for (i = 0; i < *diCount; ++i)
